==> lapisworks-1.5.6.8-sources.jar: com/luxof/lapisworks/interop/hexical/blocks/CradleEntity.java <==
package com.luxof.lapisworks.interop.hexical.blocks;

import com.luxof.lapisworks.interop.hexical.LargeItemEntity;
import com.luxof.lapisworks.interop.hexical.Lapixical;

import java.util.UUID;
import net.minecraft.class_1263;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_238;
import net.minecraft.class_243;
import net.minecraft.class_2487;
import net.minecraft.class_2586;
import net.minecraft.class_2622;
import net.minecraft.class_2680;
import net.minecraft.class_3218;

public class CradleEntity extends class_2586 implements class_1263 {
    private class_1799 heldStack = class_1799.field_8037.method_7972();
    public LargeItemEntity heldEntity = null;
    private UUID persistentUUID = UUID.randomUUID();

    public CradleEntity(class_2338 pos, class_2680 state) {
        super(Lapixical.CRADLE_ENTITY_TYPE, pos, state);
    }

    public static void tick(class_1937 world, class_2338 pos, class_2680 state, class_2586 blockE) {
        CradleEntity bE = (CradleEntity)blockE;
		bE.updateItemEntity();
		bE.configureItemEntity();
    }

    public void updateItemEntity() {
        if (field_11863.field_9236) return;
        if (heldStack.method_7960()) {
            if (heldEntity == null) return;
            persistentUUID = UUID.randomUUID();
            heldEntity.method_31472();
            heldEntity = null;
            method_5431();
            return;
        }

        class_3218 sWorld = (class_3218)field_11863;

        // just be over with please
        if (heldEntity == null || heldEntity.method_31481()) {
            class_243 pos = class_243.method_24953(this.field_11867);
            heldEntity = new LargeItemEntity(sWorld, pos.field_1352, pos.field_1351, pos.field_1350, heldStack);
            heldEntity.method_5826(persistentUUID);
            configureItemEntity();
            sWorld.method_8649(heldEntity);
        } else if (heldEntity.method_6983() != heldStack) {
            persistentUUID = UUID.randomUUID();
            heldEntity.method_31472();
            heldEntity = null;
            class_243 pos = class_243.method_24953(this.field_11867);
            heldEntity = new LargeItemEntity(sWorld, pos.field_1352, pos.field_1351, pos.field_1350, heldStack);
            heldEntity.method_5826(persistentUUID);
            configureItemEntity();
            sWorld.method_8649(heldEntity);
        }
        method_5431();
    }

    public void configureItemEntity() {
        if (heldEntity == null) return;
        class_243 pos = this.field_11867.method_46558();
        heldEntity.method_33574(pos);
        heldEntity.method_5857(new class_238( // why the fuck doesn't this work?
            pos.field_1352 - 1, pos.field_1351 - 1, pos.field_1350 - 1,
            pos.field_1352 + 1, pos.field_1351 + 1, pos.field_1350 + 1
        ));
        heldEntity.field_5960 = true;
        heldEntity.method_35190();
        heldEntity.method_5875(true);
        heldEntity.method_5648(false);
        heldEntity.method_5684(true);
        heldEntity.method_18799(class_243.field_1353);
        heldEntity.method_6989();
    }

    @Override
    public void method_11014(class_2487 nbt) {
        super.method_11014(nbt);
        heldStack = class_1799.method_7915(nbt.method_10562("item"));
        if (nbt.method_25928("persistent_uuid")) persistentUUID = nbt.method_25926("persistent_uuid");
    }

    @Override
    public void method_11007(class_2487 nbt) {
        super.method_11007(nbt);
        nbt.method_10566("item", heldStack.method_7953(new class_2487()));
        if (persistentUUID != null) {
            nbt.method_25927("persistent_uuid", persistentUUID);
        }
    }

    @Override
    public class_2622 method_38235() {
        return class_2622.method_38585(this);
    }

    @Override
    public class_2487 method_16887() {
        class_2487 nbt = new class_2487();
        method_11007(nbt);
        return nbt;
    }

    @Override
	public void method_5431() {
		field_11863.method_8413(field_11867, this.method_11010(), this.method_11010(), 3);
		super.method_5431();
	}

    @Override
    public void method_5448() {
        heldStack = class_1799.field_8037.method_7972();
        updateItemEntity();
        method_5431();
    }

    @Override
    public boolean method_5443(class_1657 player) { return false; }

    @Override
    public class_1799 method_5438(int slot) { return slot == 0 ? heldStack : class_1799.field_8037.method_7972(); }

    @Override
    public boolean method_5442() { return heldStack.method_7960(); }

    @Override
    public class_1799 method_5441(int slot) {
        if (slot != 0) return class_1799.field_8037.method_7972();
        heldStack = class_1799.field_8037.method_7972();
        updateItemEntity();
        method_5431();
        return heldStack;
    }

    @Override
    public class_1799 method_5434(int slot, int amount) {
        if (slot != 0) return class_1799.field_8037.method_7972();
        class_1799 removed = heldStack.method_7971(amount);
        updateItemEntity();
        method_5431();
        return removed;
    }

    @Override
    public void method_5447(int slot, class_1799 stack) {
        if (slot != 0) return;
        heldStack = stack;
        updateItemEntity();
        method_5431();
    }

    @Override
    public int method_5439() { return 1; }
}

==> lapisworks-1.5.7-sources.jar: com/luxof/lapisworks/interop/hexical/blocks/CradleEntity.java <==
package com.luxof.lapisworks.interop.hexical.blocks;

import com.luxof.lapisworks.interop.hexical.Lapixical;
import com.luxof.lapisworks.mixinsupport.ItemEntityMinterface;

import java.util.UUID;
import net.minecraft.class_1263;
import net.minecraft.class_1542;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_238;
import net.minecraft.class_243;
import net.minecraft.class_2487;
import net.minecraft.class_2586;
import net.minecraft.class_2622;
import net.minecraft.class_2680;
import net.minecraft.class_3218;

public class CradleEntity extends class_2586 implements class_1263 {
    private class_1799 heldStack = class_1799.field_8037.method_7972();
    public class_1542 heldEntity = null;
    private UUID persistentUUID = UUID.randomUUID();

    public CradleEntity(class_2338 pos, class_2680 state) {
        super(Lapixical.CRADLE_ENTITY_TYPE, pos, state);
    }

    public static void tick(class_1937 world, class_2338 pos, class_2680 state, class_2586 blockE) {
        CradleEntity bE = (CradleEntity)blockE;
		bE.updateItemEntity();
		bE.configureItemEntity();
    }

    public void updateItemEntity() {
        if (field_11863.field_9236) return;
        if (heldStack.method_7960()) {
            if (heldEntity == null) return;
            persistentUUID = UUID.randomUUID();
            heldEntity.method_31472();
            heldEntity = null;
            method_5431();
            return;
        }

        class_3218 sWorld = (class_3218)field_11863;

        // just be over with please
        if (heldEntity == null || heldEntity.method_31481()) {
            class_243 pos = class_243.method_24953(this.field_11867);
            heldEntity = new class_1542(sWorld, pos.field_1352, pos.field_1351, pos.field_1350, heldStack);
            heldEntity.method_5826(persistentUUID);
            configureItemEntity();
            ((ItemEntityMinterface)heldEntity).setBlockPosOfCradle(this.field_11867);
            sWorld.method_8649(heldEntity);
        } else if (heldEntity.method_6983() != heldStack) {
            persistentUUID = UUID.randomUUID();
            heldEntity.method_31472();
            heldEntity = null;
            class_243 pos = class_243.method_24953(this.field_11867);
            heldEntity = new class_1542(sWorld, pos.field_1352, pos.field_1351, pos.field_1350, heldStack);
            heldEntity.method_5826(persistentUUID);
            configureItemEntity();
            ((ItemEntityMinterface)heldEntity).setBlockPosOfCradle(this.field_11867);
            sWorld.method_8649(heldEntity);
        }
        method_5431();
    }

    public void configureItemEntity() {
        if (heldEntity == null) return;
        class_243 pos = this.field_11867.method_46558();
        heldEntity.method_33574(pos);
        heldEntity.method_5857(new class_238( // why the fuck doesn't this work?
            pos.field_1352 - 1, pos.field_1351 - 1, pos.field_1350 - 1,
            pos.field_1352 + 1, pos.field_1351 + 1, pos.field_1350 + 1
        ));
        heldEntity.field_5960 = true;
        heldEntity.method_35190();
        heldEntity.method_5875(true);
        heldEntity.method_5648(false);
        heldEntity.method_5684(true);
        heldEntity.method_18799(class_243.field_1353);
        heldEntity.method_6989();
    }

    @Override
    public void method_11014(class_2487 nbt) {
        super.method_11014(nbt);
        heldStack = class_1799.method_7915(nbt.method_10562("item"));
        if (nbt.method_25928("persistent_uuid")) persistentUUID = nbt.method_25926("persistent_uuid");
    }

    @Override
    public void method_11007(class_2487 nbt) {
        super.method_11007(nbt);
        nbt.method_10566("item", heldStack.method_7953(new class_2487()));
        if (persistentUUID != null) {
            nbt.method_25927("persistent_uuid", persistentUUID);
        }
    }

    @Override
    public class_2622 method_38235() {
        return class_2622.method_38585(this);
    }

    @Override
    public class_2487 method_16887() {
        class_2487 nbt = new class_2487();
        method_11007(nbt);
        return nbt;
    }

    @Override
	public void method_5431() {
		field_11863.method_8413(field_11867, this.method_11010(), this.method_11010(), 3);
		super.method_5431();
	}

    @Override
    public void method_5448() {
        heldStack = class_1799.field_8037.method_7972();
        updateItemEntity();
        method_5431();
    }

    @Override
    public boolean method_5443(class_1657 player) { return false; }

    @Override
    public class_1799 method_5438(int slot) { return slot == 0 ? heldStack : class_1799.field_8037.method_7972(); }

    @Override
    public boolean method_5442() { return heldStack.method_7960(); }

    @Override
    public class_1799 method_5441(int slot) {
        if (slot != 0) return class_1799.field_8037.method_7972();
        heldStack = class_1799.field_8037.method_7972();
        updateItemEntity();
        method_5431();
        return heldStack;
    }

    @Override
    public class_1799 method_5434(int slot, int amount) {
        if (slot != 0) return class_1799.field_8037.method_7972();
        class_1799 removed = heldStack.method_7971(amount);
        updateItemEntity();
        method_5431();
        return removed;
    }

    @Override
    public void method_5447(int slot, class_1799 stack) {
        if (slot != 0) return;
        heldStack = stack;
        updateItemEntity();
        method_5431();
    }

    @Override
    public int method_5439() { return 1; }
}
